==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/WebActivityAuthenticationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Web activity authentication properties.
 * @property credential The credential reference containing authentication information.
 * @property password Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
 * @property pfx Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
 * @property resource Resource for which Azure Auth token will be requested when using MSI Authentication. Type: string (or Expression with resultType string).
 * @property type Web activity authentication (Basic/ClientCertificate/MSI/ServicePrincipal)
 * @property userTenant TenantId for which Azure Auth token will be requested when using ServicePrincipal Authentication. Type: string (or Expression with resultType string).
 * @property username Web activity authentication user name for basic authentication or ClientID when used for ServicePrincipal. Type: string (or Expression with resultType string).
 */
public data class WebActivityAuthenticationArgs(
    public val credential: Output<CredentialReferenceArgs>? = null,
    public val password: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null,
    public val pfx: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null,
    public val resource: Output<Any>? = null,
    public val type: Output<String>? = null,
    public val userTenant: Output<Any>? = null,
    public val username: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs =
        com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs.builder()
            .credential(credential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .password(
                password?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .pfx(
                pfx?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .resource(resource?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 }))
            .userTenant(userTenant?.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebActivityAuthenticationArgs].
 */
@PulumiTagMarker
public class WebActivityAuthenticationArgsBuilder internal constructor() {
    private var credential: Output<CredentialReferenceArgs>? = null

    private var password: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null

    private var pfx: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null

    private var resource: Output<Any>? = null

    private var type: Output<String>? = null

    private var userTenant: Output<Any>? = null

    private var username: Output<Any>? = null

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("rvkknffsaxjfwwfp")
    public suspend fun credential(`value`: Output<CredentialReferenceArgs>) {
        this.credential = value
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("asvdrhdcijesdmeq")
    public suspend
    fun password(`value`: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>) {
        this.password = value
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("unxxfquhljtevgrp")
    public suspend
    fun pfx(`value`: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>) {
        this.pfx = value
    }

    /**
     * @param value Resource for which Azure Auth token will be requested when using MSI Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("wlmnmrlnhcfschsl")
    public suspend fun resource(`value`: Output<Any>) {
        this.resource = value
    }

    /**
     * @param value Web activity authentication (Basic/ClientCertificate/MSI/ServicePrincipal)
     */
    @JvmName("rdrcawvxdcdnujpw")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value TenantId for which Azure Auth token will be requested when using ServicePrincipal Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("utihpgwwcpkvlexk")
    public suspend fun userTenant(`value`: Output<Any>) {
        this.userTenant = value
    }

    /**
     * @param value Web activity authentication user name for basic authentication or ClientID when used for ServicePrincipal. Type: string (or Expression with resultType string).
     */
    @JvmName("yvrpbcpmpuicwgls")
    public suspend fun username(`value`: Output<Any>) {
        this.username = value
    }

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("vlbcrtqrsipcgvoy")
    public suspend fun credential(`value`: CredentialReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credential = mapped
    }

    /**
     * @param argument The credential reference containing authentication information.
     */
    @JvmName("bybpmguqoigptouu")
    public suspend fun credential(argument: suspend CredentialReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = CredentialReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.credential = mapped
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("slsjxbsstonqwbyp")
    public suspend
    fun password(`value`: Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("vsxxoapuiwxtkccb")
    public fun password(`value`: AzureKeyVaultSecretReferenceArgs) {
        val toBeMapped = Either.ofLeft<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("hpbbkcslifvlyeml")
    public fun password(`value`: SecureStringArgs) {
        val toBeMapped = Either.ofRight<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("uxdgenlqutqdonpn")
    public suspend fun pfx(`value`: Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pfx = mapped
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("xhxjdnaecfhtxbia")
    public fun pfx(`value`: AzureKeyVaultSecretReferenceArgs) {
        val toBeMapped = Either.ofLeft<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pfx = mapped
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("hhaaswrwvgksmxmd")
    public fun pfx(`value`: SecureStringArgs) {
        val toBeMapped = Either.ofRight<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pfx = mapped
    }

    /**
     * @param value Resource for which Azure Auth token will be requested when using MSI Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("yeiammfpnjamriyf")
    public suspend fun resource(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resource = mapped
    }

    /**
     * @param value Web activity authentication (Basic/ClientCertificate/MSI/ServicePrincipal)
     */
    @JvmName("jmfdplqyeeefullr")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value TenantId for which Azure Auth token will be requested when using ServicePrincipal Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("cvofbimwfmtjxcei")
    public suspend fun userTenant(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userTenant = mapped
    }

    /**
     * @param value Web activity authentication user name for basic authentication or ClientID when used for ServicePrincipal. Type: string (or Expression with resultType string).
     */
    @JvmName("ltjitftdslniklqh")
    public suspend fun username(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): WebActivityAuthenticationArgs = WebActivityAuthenticationArgs(
        credential = credential,
        password = password,
        pfx = pfx,
        resource = resource,
        type = type,
        userTenant = userTenant,
        username = username,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/WebActivityAuthenticationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs.builder
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Any
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Web activity authentication properties.
 * @property credential The credential reference containing authentication information.
 * @property password Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
 * @property pfx Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
 * @property resource Resource for which Azure Auth token will be requested when using MSI Authentication. Type: string (or Expression with resultType string).
 * @property type Web activity authentication (Basic/ClientCertificate/MSI/ServicePrincipal)
 * @property userTenant TenantId for which Azure Auth token will be requested when using ServicePrincipal Authentication. Type: string (or Expression with resultType string).
 * @property username Web activity authentication user name for basic authentication or ClientID when used for ServicePrincipal. Type: string (or Expression with resultType string).
 */
public data class WebActivityAuthenticationArgs(
    public val credential: Output<CredentialReferenceArgs>? = null,
    public val password: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null,
    public val pfx: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null,
    public val resource: Output<Any>? = null,
    public val type: Output<String>? = null,
    public val userTenant: Output<Any>? = null,
    public val username: Output<Any>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs =
        com.pulumi.azurenative.datafactory.inputs.WebActivityAuthenticationArgs.builder()
            .credential(credential?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .password(
                password?.applyValue({ args0 ->
                    args0.transform({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .pfx(
                pfx?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .resource(resource?.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 }))
            .userTenant(userTenant?.applyValue({ args0 -> args0 }))
            .username(username?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WebActivityAuthenticationArgs].
 */
@PulumiTagMarker
public class WebActivityAuthenticationArgsBuilder internal constructor() {
    private var credential: Output<CredentialReferenceArgs>? = null

    private var password: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null

    private var pfx: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>? = null

    private var resource: Output<Any>? = null

    private var type: Output<String>? = null

    private var userTenant: Output<Any>? = null

    private var username: Output<Any>? = null

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("fjsoasvucpsehuuc")
    public suspend fun credential(`value`: Output<CredentialReferenceArgs>) {
        this.credential = value
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("eymffwknyoifsiuv")
    public suspend
    fun password(`value`: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>) {
        this.password = value
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("uqesgggcwsaqneom")
    public suspend
    fun pfx(`value`: Output<Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>>) {
        this.pfx = value
    }

    /**
     * @param value Resource for which Azure Auth token will be requested when using MSI Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("rvtsihqvcprfenrl")
    public suspend fun resource(`value`: Output<Any>) {
        this.resource = value
    }

    /**
     * @param value Web activity authentication (Basic/ClientCertificate/MSI/ServicePrincipal)
     */
    @JvmName("qwlbdlwlohmjbncx")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value TenantId for which Azure Auth token will be requested when using ServicePrincipal Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("fasmkvypixyqoxjh")
    public suspend fun userTenant(`value`: Output<Any>) {
        this.userTenant = value
    }

    /**
     * @param value Web activity authentication user name for basic authentication or ClientID when used for ServicePrincipal. Type: string (or Expression with resultType string).
     */
    @JvmName("phvebmshgyksjmdg")
    public suspend fun username(`value`: Output<Any>) {
        this.username = value
    }

    /**
     * @param value The credential reference containing authentication information.
     */
    @JvmName("gutcjuemhvgcfsud")
    public suspend fun credential(`value`: CredentialReferenceArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.credential = mapped
    }

    /**
     * @param argument The credential reference containing authentication information.
     */
    @JvmName("vyqelccdbgwcaypf")
    public suspend fun credential(argument: suspend CredentialReferenceArgsBuilder.() -> Unit) {
        val toBeMapped = CredentialReferenceArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.credential = mapped
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("tfpivwalujodpkqt")
    public suspend
    fun password(`value`: Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("uhbaogeqvgvlaiap")
    public fun password(`value`: AzureKeyVaultSecretReferenceArgs) {
        val toBeMapped = Either.ofLeft<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Password for the PFX file or basic authentication / Secret when used for ServicePrincipal
     */
    @JvmName("lsvlbkrenpmffsyi")
    public fun password(`value`: SecureStringArgs) {
        val toBeMapped = Either.ofRight<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.password = mapped
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("gqicxysvanwhyspa")
    public suspend fun pfx(`value`: Either<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pfx = mapped
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("vcgihtwunanmstsy")
    public fun pfx(`value`: AzureKeyVaultSecretReferenceArgs) {
        val toBeMapped = Either.ofLeft<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pfx = mapped
    }

    /**
     * @param value Base64-encoded contents of a PFX file or Certificate when used for ServicePrincipal
     */
    @JvmName("jivexbwcujhovofl")
    public fun pfx(`value`: SecureStringArgs) {
        val toBeMapped = Either.ofRight<AzureKeyVaultSecretReferenceArgs, SecureStringArgs>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.pfx = mapped
    }

    /**
     * @param value Resource for which Azure Auth token will be requested when using MSI Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("nywoegtnhdkxcfrb")
    public suspend fun resource(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resource = mapped
    }

    /**
     * @param value Web activity authentication (Basic/ClientCertificate/MSI/ServicePrincipal)
     */
    @JvmName("elwobtwdcaciitov")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value TenantId for which Azure Auth token will be requested when using ServicePrincipal Authentication. Type: string (or Expression with resultType string).
     */
    @JvmName("adautyibaxexbapr")
    public suspend fun userTenant(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userTenant = mapped
    }

    /**
     * @param value Web activity authentication user name for basic authentication or ClientID when used for ServicePrincipal. Type: string (or Expression with resultType string).
     */
    @JvmName("lmbhgkwqikkvopep")
    public suspend fun username(`value`: Any?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.username = mapped
    }

    internal fun build(): WebActivityAuthenticationArgs = WebActivityAuthenticationArgs(
        credential = credential,
        password = password,
        pfx = pfx,
        resource = resource,
        type = type,
        userTenant = userTenant,
        username = username,
    )
}
